@@ -293,7 +293,7 @@ class TestLensingPlotterPlots:
             shape_2d=(31, 31), pixel_scales=(1.0, 1.0), radius=5.0, centre=(2.0, 2.0)
         )
 
-        masked_array = aa.masked.array.manual_2d(array=arr, mask=mask)
+        masked_array = aa.masked_array.manual_2d(array=arr, mask=mask)
 
         plotter.plot_array(array=masked_array)
 
