@@ -965,7 +965,7 @@ class TestGeneralizedNFW:
 
         mask = aa.mask.manual(mask, pixel_scales=(1.0, 1.0), sub_size=1)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
@@ -1215,7 +1215,7 @@ class TestTruncatedNFW:
 
         mask = aa.mask.manual(mask, pixel_scales=(1.0, 1.0), sub_size=1)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
@@ -1799,7 +1799,7 @@ class TestNFW:
 
         mask = aa.mask.manual(mask, pixel_scales=(1.0, 1.0), sub_size=1)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
@@ -1841,7 +1841,7 @@ class TestNFW:
 
         mask = aa.mask.manual(mask, pixel_scales=(1.0, 1.0), sub_size=1)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
