@@ -232,7 +232,7 @@ class TestPowerLaw:
 
         mask = aa.mask.manual(mask, real_space_pixel_scales=1.0)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
@@ -956,7 +956,7 @@ class TestSersicMassRadialGradient:
 
         mask = aa.mask.manual(mask, real_space_pixel_scales=1.0)
 
-        grid = aa.masked.grid.from_mask(mask=mask)
+        grid = aa.masked_grid.from_mask(mask=mask)
 
         regular_with_interp = grid.new_grid_with_interpolator(
             pixel_scale_interpolation_grid=0.5
